ecl2df
======

ecl2df is a Pandas DataFrame wrapper around libecl and opm.io, which
are used to access binary files outputted by the reservoir simulator
Eclipse, or its input files --- or any other tool outputting to the same
data format.

.. toctree::
   :maxdepth: 2

   introduction
   usage
   ecl2csv
   csv2ecl
   installation
   contribution
   history

.. toctree::
   :hidden:
   :maxdepth: 10
   :caption: Python API

   ecl2df/ecl2df

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
